@@ -10,9 +10,9 @@ from bcbio.bam import fastq
 from bcbio.provenance import do
 from Bio.SeqIO.QualityIO import FastqGeneralIterator
 from Bio.Seq import Seq
-import subprocess
-from multiprocessing import Pool
 from itertools import izip, repeat
+from bcbio.distributed.transaction import file_transaction
+
 
 SUPPORTED_ADAPTERS = {
     "illumina": ["AACACTCTTTCCCT", "AGATCGGAAGAGCG"],
@@ -58,15 +58,18 @@ def trim_read_through(fastq_files, dirs, lane_config):
     quality_format = _get_quality_format(lane_config)
     to_trim = _get_sequences_to_trim(lane_config)
     out_files = _get_read_through_trimmed_outfiles(fastq_files, dirs)
+    fixed_files = append_stem(out_files, ".fixed")
+    if all(map(file_exists, fixed_files)):
+        return fixed_files
     logger.info("Trimming %s from the 3' end of reads in %s using "
                 "cutadapt." % (", ".join(to_trim),
                                ", ".join(fastq_files)))
     cores = lane_config["algorithm"].get("num_cores", 1)
     out_files = _cutadapt_trim(fastq_files, quality_format,
                                to_trim, out_files, cores)
-    trimmed_files = _remove_short_reads(out_files, dirs, lane_config)
-    return trimmed_files
 
+    fixed_files = remove_short_reads(out_files, dirs, lane_config)
+    return fixed_files
 
 
 def _trim_quality(seq, qual, to_trim, min_length):
@@ -131,7 +134,7 @@ def _save_diskspace(in_file, out_file, config):
 
 
 
-def _remove_short_reads(fastq_files, dirs, lane_config):
+def remove_short_reads(fastq_files, dirs, lane_config):
     """
     remove reads from a single or pair of fastq files which fall below
     a length threshold (30 bases)
@@ -152,6 +155,7 @@ def _remove_short_reads(fastq_files, dirs, lane_config):
         out_files = [fastq.filter_single_reads_by_length(fastq_files[0],
                                                         quality_format,
                                                         MIN_LENGTH)]
+    map(os.remove, fastq_files)
     return out_files
 
 def _get_read_through_trimmed_outfiles(fastq_files, dirs):
@@ -198,9 +202,11 @@ def _cutadapt_trim(fastq_files, quality_format, adapters, out_files, cores):
     base_cmd.extend(adapter_cmd)
     if all(map(file_exists, out_files)):
         return out_files
-    pool = Pool(processes=cores)
-    pool.map(_run_cutadapt_on_single_file, izip(repeat(base_cmd), fastq_files,
-                                                out_files))
+    with file_transaction(out_files) as tmp_out_files:
+        if isinstance(tmp_out_files, basestring):
+            tmp_out_files = [tmp_out_files]
+        map(_run_cutadapt_on_single_file, izip(repeat(base_cmd), fastq_files,
+                                               tmp_out_files))
     return out_files
 
 @map_wrap
@@ -211,14 +217,6 @@ def _run_cutadapt_on_single_file(base_cmd, fastq_file, out_file):
         cmd.extend(["--output=" + out_file, fastq_file])
         do.run(cmd, "Running cutadapt on %s." % (fastq_file), None)
 
-def _run_with_possible_error_message(cmd, **kwargs):
-    try:
-        subprocess.check_call(cmd, **kwargs)
-    except subprocess.CalledProcessError:
-        cmd_string = subprocess.list2cmdline(cmd)
-        logger.error("Cutadapt returned an error. The command "
-                     "used to run cutadapt was: %s." % (cmd_string))
-        exit(1)
 
 def _get_quality_format(lane_config):
     SUPPORTED_FORMATS = ["illumina", "standard"]
