@@ -6,8 +6,10 @@ from IPython.parallel import require
 
 from bcbio.distributed import ipython
 from bcbio.ngsalign import alignprep
-from bcbio.pipeline import sample, lane, qcsummary, shared, variation
+from bcbio.pipeline import disambiguate, sample, lane, qcsummary, shared, variation
 from bcbio.provenance import system
+from bcbio import structural
+from bcbio import chipseq
 from bcbio.variation import (bamprep, coverage, realign, genotype, ensemble, multi, population,
                              recalibrate, validate, vcfutils)
 from bcbio.log import logger, setup_local_logging
@@ -29,11 +31,12 @@ def _setup_logging(args):
     handler = setup_local_logging(config, config.get("parallel", {}))
     try:
         yield None
-        if hasattr(handler, "close"):
-            handler.close()
     except:
         logger.exception("Unexpected error")
         raise
+    finally:
+        if hasattr(handler, "close"):
+            handler.close()
 
 @require(lane)
 def process_lane(*args):
@@ -49,7 +52,7 @@ def trim_lane(*args):
 def process_alignment(*args):
     with _setup_logging(args):
         return apply(lane.process_alignment, *args)
-process_alignment.metadata = {"resources": ["novoalign", "bwa", "bowtie", "tophat"]}
+process_alignment.metadata = {"resources": ["novoalign", "bwa", "bowtie2", "tophat2"]}
 
 @require(alignprep)
 def prep_align_inputs(*args):
@@ -153,10 +156,10 @@ def prep_gemini_db(*args):
         return apply(population.prep_gemini_db, *args)
 prep_gemini_db.metadata = {"resources": ["gemini"]}
 
-@require(variation)
+@require(structural)
 def detect_sv(*args):
     with _setup_logging(args):
-        return apply(variation.detect_sv, *args)
+        return apply(structural.detect_sv, *args)
 
 @require(ensemble)
 def combine_calls(*args):
@@ -174,6 +177,15 @@ def coverage_summary(*args):
         return apply(coverage.summary, *args)
 coverage_summary.metadata = {"resources": ["bcbio_coverage"]}
 
+@require(disambiguate)
+def run_disambiguate(*args):
+    with _setup_logging(args):
+        return apply(disambiguate.run, *args)
+
 @require(system)
 def machine_info(*args):
     return system.machine_info()
+
+@require(chipseq)
+def clean_chipseq_alignment(*args):
+    return chipseq.machine_info()
