@@ -1,11 +1,12 @@
 """Multiprocessing ready entry points for sample analysis.
 """
-from bcbio import utils
+from bcbio import structural, utils
 from bcbio.bam import callable
 from bcbio.ngsalign import alignprep
-from bcbio.pipeline import lane, qcsummary, sample, shared, variation
+from bcbio.pipeline import disambiguate, lane, qcsummary, sample, shared, variation
 from bcbio.variation import (bamprep, coverage, realign, genotype, ensemble, multi, population,
                              recalibrate, validate, vcfutils)
+from bcbio import chipseq
 
 @utils.map_wrap
 def process_lane(*args):
@@ -95,7 +96,7 @@ def concat_variant_files(*args):
 
 @utils.map_wrap
 def detect_sv(*args):
-    return variation.detect_sv(*args)
+    return structural.detect_sv(*args)
 
 @utils.map_wrap
 def combine_calls(*args):
@@ -122,3 +123,11 @@ def compare_to_rm(*args):
 def coverage_summary(*args):
     return coverage.summary(*args)
 coverage_summary.metadata = {"resources": ["bcbio_coverage"]}
+
+@utils.map_wrap
+def run_disambiguate(*args):
+    return disambiguate.run(*args)
+
+@utils.map_wrap
+def clean_chipseq_alignment(*args):
+    return chipseq.clean_chipseq_alignment(*args)
