@@ -5,7 +5,9 @@ import time
 from celery.task import task
 
 from bcbio.pipeline import sample, lane, qcsummary, toplevel, storage, shared, variation, validate
+from bcbio import structural
 from bcbio.variation import realign, genotype, ensemble, population, multi, recalibrate, vcfutils
+from bcbio import chipseq
 
 # Global configuration for tasks in the main celeryconfig module
 import celeryconfig
@@ -97,7 +99,7 @@ def concat_variant_files(*args):
 
 @task
 def detect_sv(*args):
-    return variation.detect_sv(*args)
+    return structural.detect_sv(*args)
 
 @task
 def combine_calls(*args):
@@ -116,3 +118,7 @@ def test(x):
     print x
     time.sleep(5)
     return x
+
+@task
+def clean_chipseq_aligment(*args):
+    return chipseq.clean_chipseq_alignment(*args)
