@@ -20,8 +20,7 @@ REMOTES = {
     "requirements": "https://raw.github.com/chapmanb/bcbio-nextgen/master/requirements.txt",
     "gitrepo": "git://github.com/chapmanb/bcbio-nextgen.git",
     "cloudbiolinux": "https://github.com/chapmanb/cloudbiolinux.git",
-    "genome_resources": "https://raw.github.com/chapmanb/bcbio-nextgen/master/config/genomes/%s-resources.yaml",
-    }
+    "genome_resources": "https://raw.github.com/chapmanb/bcbio-nextgen/master/config/genomes/%s-resources.yaml"}
 
 def upgrade_bcbio(args):
     """Perform upgrade of bcbio to latest release, or from GitHub development version.
@@ -40,9 +39,9 @@ def upgrade_bcbio(args):
     else:
         _update_conda_packages()
         print("Upgrading bcbio-nextgen to latest development version")
+        subprocess.check_call([pip_bin, "install", "git+%s#egg=bcbio-nextgen" % REMOTES["gitrepo"]])
         subprocess.check_call([pip_bin, "install", "--upgrade", "--no-deps",
                                "git+%s#egg=bcbio-nextgen" % REMOTES["gitrepo"]])
-        subprocess.check_call([pip_bin, "install", "git+%s#egg=bcbio-nextgen" % REMOTES["gitrepo"]])
 
     if args.tooldir:
         with bcbio_tmpdir():
@@ -70,18 +69,18 @@ def _default_deploy_args(args):
             "custom_add": dict(custom_add),
             "vm_provider": "novm",
             "hostname": "localhost",
-            "fabricrc_overrides" : {"edition": "minimal",
-                                    "use_sudo": args.sudo,
-                                    "keep_isolated": args.isolate,
-                                    "distribution": args.distribution or "__auto__",
-                                    "dist_name": "__auto__"}}
+            "fabricrc_overrides": {"edition": "minimal",
+                                   "use_sudo": args.sudo,
+                                   "keep_isolated": args.isolate,
+                                   "distribution": args.distribution or "__auto__",
+                                   "dist_name": "__auto__"}}
 
 def _update_conda_packages():
     """If installed in an anaconda directory, upgrade conda packages.
     """
     conda_bin = os.path.join(os.path.dirname(sys.executable), "conda")
-    pkgs = ["biopython", "boto", "cython", "distribute", "ipython", "nose", "numpy",
-            "pycrypto", "pip", "pysam", "pyyaml", "pyzmq", "requests", "tornado"]
+    pkgs = ["biopython", "boto", "cython", "ipython", "lxml", "matplotlib", "nose", "numpy",
+            "pycrypto", "pip", "pysam", "pyyaml", "pyzmq", "requests", "tornado", "statsmodels"]
     if os.path.exists(conda_bin):
         subprocess.check_call([conda_bin, "install", "--yes"] + pkgs)
         # Remove until can get 13.1.0 working cleanly on CentOS
@@ -209,10 +208,16 @@ def add_install_defaults(args):
     if default_args.get("tooldist") and args.tooldist == "minimal":
         args.tooldist = default_args["tooldist"]
     if args.tools and args.tooldir is None:
-        args.tooldir = default_args["tooldir"]
+        if "tooldir" in default_args:
+            args.tooldir = default_args["tooldir"]
+        else:
+            raise ValueError("Default tool directory not yet saved in config defaults. "
+                             "Specify the '--tooldir=/path/to/tools' to upgrade tools. "
+                             "After a successful upgrade, the '--tools' parameter will "
+                             "work for future upgrades.")
     for attr in ["genomes", "aligners", "toolplus"]:
         for x in default_args.get(attr, []):
-            new_val =  getattr(args, attr)
+            new_val = getattr(args, attr)
             if x not in getattr(args, attr):
                 new_val.append(x)
             setattr(args, attr, new_val)
@@ -222,6 +227,13 @@ def add_install_defaults(args):
         args.isolate = default_args["isolate"]
     return args
 
+def get_defaults():
+    install_config = _get_install_config()
+    if install_config is None or not utils.file_exists(install_config):
+        return {}
+    with open(install_config) as in_handle:
+        return yaml.load(in_handle)
+
 def add_subparser(subparsers):
     parser = subparsers.add_parser("upgrade", help="Install or upgrade bcbio-nextgen")
     parser.add_argument("--tooldir",
@@ -231,15 +243,15 @@ def add_subparser(subparsers):
                         help="Boolean argument specifying upgrade of tools. Uses previously saved install directory",
                         action="store_true", default=False)
     parser.add_argument("-u", "--upgrade", help="Code version to upgrade",
-                        choices = ["stable", "development", "system", "skip"], default="stable")
+                        choices=["stable", "development", "system", "skip"], default="skip")
     parser.add_argument("--toolplus", help="Specify additional tool categories to install",
                         action="append", default=[], choices=["protected", "data"])
     parser.add_argument("--genomes", help="Genomes to download",
                         action="append", default=["GRCh37"])
     parser.add_argument("--aligners", help="Aligner indexes to download",
                         action="append", default=["bwa"])
-    parser.add_argument("--nodata", help="Do not install data dependencies",
-                        dest="install_data", action="store_false", default=True)
+    parser.add_argument("--data", help="Upgrade data dependencies",
+                        dest="install_data", action="store_true", default=False)
     parser.add_argument("--nosudo", help="Specify we cannot use sudo for commands",
                         dest="sudo", action="store_false", default=True)
     parser.add_argument("--isolate", help="Created an isolated installation without PATH updates",
