@@ -24,10 +24,11 @@ def _bowtie_args_from_config(config):
     core_flags = ["-p", str(num_cores)] if num_cores > 1 else []
     return core_flags + qual_flags + multi_flags
 
-def align(fastq_file, pair_file, ref_file, out_base, align_dir, config,
+def align(fastq_file, pair_file, ref_file, out_base, align_dir, data,
           extra_args=None, names=None):
     """Do standard or paired end alignment with bowtie.
     """
+    config = data['config']
     out_file = os.path.join(align_dir, "%s.sam" % out_base)
     if not file_exists(out_file):
         with file_transaction(out_file) as tx_out_file:
