@@ -7,7 +7,7 @@ import os
 
 from Bio.SeqIO.QualityIO import FastqGeneralIterator
 
-from bcbio import utils, broad
+from bcbio import bam, broad, utils
 from bcbio.bam import cram
 from bcbio.distributed.transaction import file_transaction
 from bcbio.ngsalign import (bowtie, bwa, tophat, bowtie2, mosaik,
@@ -50,7 +50,10 @@ def align_to_sort_bam(fastq1, fastq2, aligner, data):
     """Align to the named genome build, returning a sorted BAM file.
     """
     names = data["rgnames"]
-    align_dir = utils.safe_makedir(os.path.join(data["dirs"]["work"], "align", names["sample"]))
+    align_dir_parts = [data["dirs"]["work"], "align", names["sample"]]
+    if data.get("disambiguate"):
+        align_dir_parts.append(data["disambiguate"]["genome_build"])
+    align_dir = utils.safe_makedir(apply(os.path.join, align_dir_parts))
     if fastq1.endswith(".bam"):
         out_bam = _align_from_bam(fastq1, aligner, data["align_ref"], data["sam_ref"],
                                   names, align_dir, data)
@@ -62,9 +65,8 @@ def align_to_sort_bam(fastq1, fastq2, aligner, data):
         out_bam = _align_from_fastq(fastq1, fastq2, aligner, data["align_ref"], data["sam_ref"],
                                     names, align_dir, data)
         data["work_bam"] = out_bam
-    runner = broad.runner_from_config(data["config"])
     if data["work_bam"] and utils.file_exists(data["work_bam"]):
-        runner.run_fn("picard_index", data["work_bam"])
+        bam.index(data["work_bam"], data["config"])
     return data
 
 def _can_pipe(aligner, fastq_file):
@@ -102,7 +104,7 @@ def _align_from_fastq(fastq1, fastq2, aligner, align_ref, sam_ref, names,
     assert not data.get("align_split"), "Do not handle split alignments with non-piped fastq yet"
     config = data["config"]
     align_fn = TOOLS[aligner].align_fn
-    sam_file = align_fn(fastq1, fastq2, align_ref, names["lane"], align_dir, config,
+    sam_file = align_fn(fastq1, fastq2, align_ref, names["lane"], align_dir, data,
                         names=names)
     if fastq2 is None and aligner in ["bwa", "bowtie2", "tophat2"]:
         fastq1 = _remove_read_number(fastq1, sam_file)
@@ -125,6 +127,10 @@ def _remove_read_number(in_file, sam_file):
     """
     out_file = os.path.join(os.path.dirname(sam_file),
                             "%s-safe%s" % os.path.splitext(os.path.basename(in_file)))
+    # file already exists and is zero means we already skipped the removal and
+    # are just using the original file
+    if os.path.exists(out_file) and os.path.getsize(out_file) == 0:
+        return in_file
     if not os.path.exists(out_file):
         with file_transaction(out_file) as tx_out_file:
             with open(in_file) as in_handle:
@@ -179,4 +185,3 @@ def sam_to_sort_bam(sam_file, ref_file, fastq1, fastq2, names, config):
         if fastq2:
             utils.save_diskspace(fastq2, "Merged into output BAM %s" % out_bam, config)
     return sort_bam
-
