@@ -9,14 +9,13 @@ import argparse
 from collections import defaultdict
 import tempfile
 
-from bcbio import install, log, utils, upload
+from bcbio import install, log, structural, utils, upload
 from bcbio.bam import callable
-from bcbio.rnaseq import qc
 from bcbio.distributed.messaging import parallel_runner
 from bcbio.distributed.ipython import global_parallel
 from bcbio.log import logger
 from bcbio.ngsalign import alignprep
-from bcbio.pipeline import lane, region, run_info, qcsummary, version
+from bcbio.pipeline import disambiguate, lane, region, run_info, qcsummary, version
 from bcbio.pipeline.config_utils import load_system_config
 from bcbio.provenance import programs, system, versioncheck
 from bcbio.server import main as server_main
@@ -94,7 +93,6 @@ def _run_toplevel(config, config_file, work_dir, parallel,
                 if len(xs) == 1:
                     upload.from_sample(xs[0])
                     final.append(xs[0])
-        qcsummary.write_metrics(final, dirs)
 
 def _add_provenance(items, dirs, run_parallel, parallel, config):
     p = programs.write_versions(dirs, config)
@@ -216,6 +214,10 @@ def _add_inputs_to_kwargs(args, kwargs, parser):
         print "Incorrect input arguments", inputs
         parser.print_help()
         sys.exit()
+    if fc_dir:
+        fc_dir = os.path.abspath(fc_dir)
+    if run_info_yaml:
+        run_info_yaml = os.path.abspath(run_info_yaml)
     kwargs["inputs"] = inputs
     kwargs["config_file"] = global_config
     kwargs["fc_dir"] = fc_dir
@@ -332,10 +334,12 @@ class Variant2Pipeline(AbstractPipeline):
             run_parallel = parallel_runner(parallel, dirs, config)
             logger.info("Timing: prepped BAM merging")
             samples = region.delayed_bamprep_merge(samples, run_parallel)
-            logger.info("Timing: quality control")
-            samples = qcsummary.generate_parallel(samples, run_parallel)
+            logger.info("Timing: structural variation")
+            samples = structural.run(samples, run_parallel)
             logger.info("Timing: population database")
             samples = population.prep_db_parallel(samples, run_parallel)
+            logger.info("Timing: quality control")
+            samples = qcsummary.generate_parallel(samples, run_parallel)
         logger.info("Timing: finished")
         return samples
 
@@ -374,13 +378,26 @@ class RnaseqPipeline(AbstractPipeline):
     @classmethod
     def run(self, config, config_file, run_parallel, parallel, dirs, lane_items):
         lane_items = run_parallel("trim_lane", lane_items)
-        samples = run_parallel("process_alignment", lane_items)
+        samples = disambiguate.split(lane_items)
+        samples = run_parallel("process_alignment", samples)
+        samples = disambiguate.resolve(samples, run_parallel)
         samples = run_parallel("generate_transcript_counts", samples)
         samples = qcsummary.generate_parallel(samples, run_parallel)
-        samples = qc.sample_summary(samples)
         #run_parallel("generate_bigwig", samples, {"programs": ["ucsc_bigwig"]})
         return samples
 
+class ChipseqPipeline(AbstractPipeline):
+    name = "chip-seq"
+
+    @classmethod
+    def run(self, config, config_file, run_parallel, parallel, dirs, lane_items):
+        lane_items = run_parallel("trim_lane", lane_items)
+        samples = disambiguate.split(lane_items)
+        samples = run_parallel("process_alignment", samples)
+        samples = run_parallel("clean_chipseq_alignment", samples)
+        samples = qcsummary.generate_parallel(samples, run_parallel)
+        return samples
+
 def _get_pipeline(item):
     from bcbio.log import logger
     SUPPORTED_PIPELINES = {x.name.lower(): x for x in
