@@ -43,20 +43,21 @@ def organize(dirs, config, run_info_yaml):
         item["dirs"] = dirs
         if "name" not in item:
             item["name"] = ["", item["description"]]
-        item = _add_reference_resources(item)
+        item = add_reference_resources(item)
         out.append(item)
     return out
 
 # ## Genome reference information
 
-def _add_reference_resources(data):
+def add_reference_resources(data):
     """Add genome reference information to the item to process.
     """
     aligner = data["config"]["algorithm"].get("aligner", None)
     align_ref, sam_ref = genome.get_refs(data["genome_build"], aligner, data["dirs"]["galaxy"])
     data["align_ref"] = align_ref
     data["sam_ref"] = sam_ref
-    data["genome_resources"] = genome.get_resources(data["genome_build"], sam_ref)
+    ref_loc = data["config"].get("resources", {}).get("species", {}).get("dir", sam_ref)
+    data["genome_resources"] = genome.get_resources(data["genome_build"], ref_loc)
     return data
 
 # ## Sample and BAM read group naming
@@ -137,12 +138,12 @@ def _check_algorithm_keys(item):
                      "write_summary", "merge_bamprep", "coverage", "coverage_bigwig",
                      "coverage_depth", "coverage_interval", "hybrid_target", "hybrid_bait",
                      "ploidy",
-                     "variantcaller", "variant_regions", "mark_duplicates",
+                     "variantcaller", "variant_regions", "mark_duplicates", "svcaller",
                      "recalibrate", "realign",
                      "phasing", "validate", "validate_regions", "validate_genome_build",
                      "clinical_reporting",
                      "nomap_split_size", "nomap_split_targets",
-                     "ensemble"])
+                     "ensemble", "disambiguate"])
     problem_keys = [k for k in item["algorithm"].iterkeys() if k not in supported]
     if len(problem_keys) > 0:
         raise ValueError("Unexpected configuration keyword in 'algorithm' section: %s\n"
@@ -241,7 +242,7 @@ def _run_info_from_yaml(fc_dir, run_info_yaml, config):
         item["upload"] = upload
         item["algorithm"] = genome.abs_file_paths(item["algorithm"],
                                                   ignore_keys=["variantcaller", "realign", "recalibrate",
-                                                               "phasing"])
+                                                               "phasing", "svcaller"])
         item["rgnames"] = prep_rg_names(item, config, fc_name, fc_date)
         run_details.append(item)
     _check_sample_config(run_details, run_info_yaml)
