@@ -6,7 +6,7 @@ from contextlib import closing
 import pybedtools
 import pysam
 
-from bcbio import broad
+from bcbio import bam, broad
 from bcbio.pipeline import config_utils
 from bcbio.utils import file_exists, safe_makedir, save_diskspace
 from bcbio.distributed.transaction import file_transaction
@@ -21,7 +21,7 @@ def combine_bam(in_files, out_file, config):
     runner.run_fn("picard_merge", in_files, out_file)
     for in_file in in_files:
         save_diskspace(in_file, "Merged into {0}".format(out_file), config)
-    runner.run_fn("picard_index", out_file)
+    bam.index(out_file, config)
     return out_file
 
 def process_bam_by_chromosome(output_ext, file_key, default_targets=None, dir_ext_fn=None):
@@ -111,22 +111,17 @@ def subset_bam_by_region(in_file, region, out_file_base=None):
                             out_bam.write(read)
     return out_file
 
-def _line_in_region(line, chrom, start, end):
-    """Check if the region defined by the BED line falls into chrom, start, end
-    """
-    if start is not None:
-        start = int(start)
-        end = int(end)
-    if line.startswith(chrom):
-        parts = line.split()
-        if parts[0] == chrom:
-            cur_start = int(parts[1])
-            cur_end = int(parts[2])
-            if (start is None or
-                    (cur_start >= start and cur_start <= end) or
-                    (cur_end >= start and cur_end <= end)):
-                return cur_start
-    return None
+def _rewrite_bed_with_chrom(in_file, out_file, chrom):
+    with open(in_file) as in_handle:
+        with open(out_file, "w") as out_handle:
+            for line in in_handle:
+                if line.startswith("%s\t" % chrom):
+                    out_handle.write(line)
+
+def _subset_bed_by_region(in_file, out_file, region):
+    orig_bed = pybedtools.BedTool(in_file)
+    region_bed = pybedtools.BedTool("\t".join(str(x) for x in region) + "\n", from_string=True)
+    orig_bed.intersect(region_bed).saveas(out_file)
 
 def subset_variant_regions(variant_regions, region, out_file):
     """Return BED file subset by a specified chromosome region.
@@ -141,25 +136,16 @@ def subset_variant_regions(variant_regions, region, out_file):
     elif not isinstance(region, (list, tuple)) and region.find(":") > 0:
         raise ValueError("Partial chromosome regions not supported")
     else:
-        if isinstance(region, (list, tuple)):
-            chrom, rstart, rend = region
-        else:
-            chrom = region
-            rstart, rend = None, None
-        # create an ordered subset file for processing
         subset_file = "{0}-regions.bed".format(os.path.splitext(out_file)[0])
-        items = []
-        with open(variant_regions) as in_handle:
-            for line in in_handle:
-                cur_start = _line_in_region(line, chrom, rstart, rend)
-                if cur_start is not None:
-                    items.append((cur_start, line))
-        if len(items) > 0:
-            if not os.path.exists(subset_file):
-                with open(subset_file, "w") as out_handle:
-                    items.sort()
-                    for _, line in items:
-                        out_handle.write(line)
-            return subset_file
-        else:
+        if not os.path.exists(subset_file):
+            with file_transaction(subset_file) as tx_subset_file:
+                if isinstance(region, (list, tuple)):
+                    c, s, e = region
+                    safe_region = [c, s, e - 2]
+                    _subset_bed_by_region(variant_regions, tx_subset_file, safe_region)
+                else:
+                    _rewrite_bed_with_chrom(variant_regions, tx_subset_file, region)
+        if os.path.getsize(subset_file) == 0:
             return region
+        else:
+            return subset_file
