@@ -33,6 +33,8 @@ def _get_files(sample):
         return _get_files_variantcall(sample)
     elif analysis in ["RNA-seq"]:
         return _get_files_rnaseq(sample)
+    elif analysis.lower() in ["chip-seq"]:
+        return _get_files_chipseq(sample)
     else:
         return []
 
@@ -43,6 +45,13 @@ def _get_files_rnaseq(sample):
     out = _maybe_add_alignment(algorithm, sample, out)
     return _add_meta(out, sample)
 
+def _get_files_chipseq(sample):
+    out = []
+    algorithm = sample["config"]["algorithm"]
+    out = _maybe_add_summary(algorithm, sample, out)
+    out = _maybe_add_alignment(algorithm, sample, out)
+    return _add_meta(out, sample)
+
 def _add_meta(xs, sample=None, config=None):
     out = []
     for x in xs:
@@ -83,11 +92,16 @@ def _maybe_add_variant_file(algorithm, sample, out):
 
 
 def _maybe_add_summary(algorithm, sample, out):
-    if algorithm.get("write_summary", True) and "summary" in sample:
+    out = []
+    if "summary" in sample:
         if sample["summary"].get("pdf"):
-            out = [{"path": sample["summary"]["pdf"],
-                    "type": "pdf",
-                    "ext": "summary"}]
+            out.append({"path": sample["summary"]["pdf"],
+                       "type": "pdf",
+                       "ext": "summary"})
+        if sample["summary"].get("qc"):
+            out.append({"path": sample["summary"]["qc"],
+                        "type": "directory",
+                        "ext": "qc"})
     return out
 
 def _maybe_add_alignment(algorithm, sample, out):
