@@ -8,6 +8,8 @@ from bcbio.log import logger
 from bcbio.upload import shared
 
 def copy_finfo(finfo, storage_dir):
+    """Copy a file into the output storage directory.
+    """
     if finfo.has_key("sample"):
         out_file = os.path.join(storage_dir, "%s-%s.%s" % (finfo["sample"], finfo["ext"],
                                                            finfo["type"]))
@@ -19,6 +21,17 @@ def copy_finfo(finfo, storage_dir):
         shutil.copy(finfo["path"], out_file)
         return out_file
 
+def copy_finfo_directory(finfo, storage_dir):
+    """Copy a directory into the final output directory.
+    """
+    out_dir = os.path.abspath(os.path.join(storage_dir, finfo["ext"]))
+    if not shared.up_to_date(out_dir, finfo):
+        logger.info("Storing directory in local filesystem: %s" % out_dir)
+        if utils.file_exists(out_dir):
+            shutil.rmtree(out_dir)
+        shutil.copytree(finfo["path"], out_dir)
+    return out_dir
+
 def update_file(finfo, sample_info, config):
     """Update the file in local filesystem storage.
     """
@@ -31,4 +44,7 @@ def update_file(finfo, sample_info, config):
         storage_dir = utils.safe_makedir(os.path.join(config["dir"], finfo["run"]))
     else:
         raise ValueError("Unexpected input file information: %s" % finfo)
-    return copy_finfo(finfo, storage_dir)
+    if finfo.get("type") == "directory":
+        return copy_finfo_directory(finfo, storage_dir)
+    else:
+        return copy_finfo(finfo, storage_dir)
